@@ -1,7 +1,7 @@
 import os 
 import sqlite3 
 
-__version__ = version = '2.1.2'
+__version__ = version = '2.1.5'
 
 SPECIAL_CHARS = r"~!#$%^&*()-=+[]\{}:;,._||" + r'"' + r"'<>?/0123456789"
 INSERT_SPECIAL_CHARS = r"0123456789" + r"-_()[]:/.,@#&" 
@@ -29,14 +29,9 @@ def __sroutine1():
     subprocess.call([sys.executable, '-m' , 'meteor_diceware.utils' , 'create' , 'main' , '-w'])
     subprocess.call([sys.executable , '-m' , 'meteor_diceware.utils' , 'edit' , 'main' , '-f' , os.path.join(ProgPath , 'actual_diceware.txt')])
 
-def __initdb():
+__initdb = lambda : DBCursor.executescript(open(os.path.join(ProgPath , 'init.sql') , 'r' , encoding = 'utf8').read())
 
-    global DBCursor , ProgPath 
 
-    DBCursor.execute('begin')
-    DBCursor.executescript(open(os.path.join(ProgPath , 'init.sql') , 'r' , encoding = 'utf8').read())
-    DBCursor.execute('commit')
-    
 try:
     
     __selroutine()
